struct PointsToAnalysis<'a> {
fn_sig: Option<&'a EarlyBinder<PolyFnSig>>,
map: &'a Map,
}Expand description
This implement a points to analysis for mutable references over a [FlatSet]. The analysis is
a may analysis. If you want to know if a reference definitively points to a location you have to
combine it with the result of a definitely initialized analysis. See module level documentation
for more details.
Fields
fn_sig: Option<&'a EarlyBinder<PolyFnSig>>map: &'a MapImplementations
Sourceimpl<'a> PointsToAnalysis<'a>
impl<'a> PointsToAnalysis<'a>
fn new(map: &'a Map, fn_sig: Option<&'a EarlyBinder<PolyFnSig>>) -> Self
fn handle_statement(&self, statement: &Statement<'_>, state: &mut State)
fn handle_assign( &self, target: Place<'_>, rvalue: &Rvalue<'_>, state: &mut State, )
Sourcefn handle_ref(&self, place: &Place<'_>, state: &State) -> FlatSet<Path>
fn handle_ref(&self, place: &Place<'_>, state: &State) -> FlatSet<Path>
This mirrors the way PlacesTree::lookup_inner walks a place: a dereference moves the root
of the path to whatever the pointer points to, and fields are accumulated onto it.
fn handle_operand(&self, operand: &Operand<'_>) -> Option<PlaceIndex>
Sourcefn handle_terminator<'tcx>(
&self,
terminator: &Terminator<'tcx>,
state: &mut State,
)
fn handle_terminator<'tcx>( &self, terminator: &Terminator<'tcx>, state: &mut State, )
The effect of a successful function call return should not be
applied here, see [Analysis::apply_primary_terminator_effect].
fn handle_call_return( &self, return_places: CallReturnPlaces<'_, '_>, state: &mut State, )